==> firefox-58.0b13.source.tar.xz: firefox-58.0b13/browser/extensions/activity-stream/prerendered/locales/ar/activity-stream-strings.js <==
// Note - this is a generated file.
window.gActivityStreamStrings = {
  "newtab_page_title": "لسان جديد",
  "default_label_loading": "يُحمّل…",
  "header_top_sites": "المواقع الأكثر زيارة",
  "header_stories": "أهم الأخبار",
  "header_highlights": "أهم الأحداث",
  "header_visit_again": "زرها مجددا",
  "header_bookmarks": "أحدث العلامات",
  "header_recommended_by": "ينصح به {provider}",
  "header_bookmarks_placeholder": "لا علامات لديك بعد.",
  "header_stories_from": "من",
  "type_label_visited": "مُزارة",
  "type_label_bookmarked": "معلّمة",
  "type_label_synced": "مُزامنة من جهاز آخر",
  "type_label_recommended": "مُتداول",
  "type_label_open": "مفتوحة",
  "type_label_topic": "الموضوع",
  "type_label_now": "الآن",
  "menu_action_bookmark": "علّم",
  "menu_action_remove_bookmark": "أزل العلامة",
  "menu_action_copy_address": "انسخ العنوان",
  "menu_action_email_link": "أرسل الرابط بالبريد…",
  "menu_action_open_new_window": "افتح في نافذة جديدة",
  "menu_action_open_private_window": "افتح في نافذة خاصة جديدة",
  "menu_action_dismiss": "ألغِ",
  "menu_action_delete": "احذف من التأريخ",
  "menu_action_pin": "ثبّت",
  "menu_action_unpin": "أزل",
  "confirm_history_delete_p1": "هل أنت متأكد أنك تريد حذف كل وجود لهذه الصفحة من تأريخك؟",
  "confirm_history_delete_notice_p2": "لا يمكن التراجع عن هذا الإجراء.",
  "menu_action_save_to_pocket": "احفظ في Pocket",
  "search_for_something_with": "ابحث عن {search_term} مستخدما:",
  "search_button": "ابحث",
  "search_header": "بحث {search_engine_name}",
  "search_web_placeholder": "ابحث في الوِب",
  "search_settings": "غيّر إعدادات البحث",
  "section_info_option": "المعلومات",
  "section_info_send_feedback": "أرسل انطباعك",
  "section_info_privacy_notice": "تنويه الخصوصية",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "welcome_title": "مرحبًا في لسان جديد",
  "welcome_body": "سيستخدم فيرفكس هذا المكان لعرض أكثر العلامات، و المقالات، و الفيديوهات والصفحات التي زرتها مؤخرا، ليمكنك العودة إليها بسهولة.",
  "welcome_label": "تعرّف على أهم الأخبار",
  "time_label_less_than_minute": "< دقيقة",
  "time_label_minute": "{number} دقيقة",
  "time_label_hour": "{number} ساعة",
  "time_label_day": "{number} يوم",
  "settings_pane_button_label": "خصص صفحة اللسان الجديد",
  "settings_pane_header": "تفضيلات صفحة اللسان الجديد",
  "settings_pane_body2": "اختر ماتريد ان تراه في هذه الصفحه.",
  "settings_pane_search_header": "بحث",
  "settings_pane_search_body": "ابحث في الوِب من اللسان الجديد.",
  "settings_pane_topsites_header": "المواقع الأكثر زيارة",
  "settings_pane_topsites_body": "وصول للمواقع التي تزورها أكثر.",
  "settings_pane_topsites_options_showmore": "اعرض صفّين",
  "settings_pane_bookmarks_header": "أحدث العلامات",
  "settings_pane_bookmarks_body": "علاماتك المعلّمة حديثًا في مكان واحد.",
  "settings_pane_visit_again_header": "زرها مجددا",
  "settings_pane_visit_again_body": "سيعرض لك فَيَرفُكس بعضًا من تأريخ تصفحك الذي قد تود تذكّره لاحقًا.",
  "settings_pane_highlights_header": "أهم الأحداث",
  "settings_pane_highlights_body2": "ارجع للأشياء المهمة التي زرتها مؤخرًا أو العلامات.",
  "settings_pane_highlights_options_bookmarks": "العلامات",
  "settings_pane_highlights_options_visited": "المواقع المُزارة",
  "settings_pane_snippets_header": "المقتطفات",
  "settings_pane_snippets_body": "اقرأ تحديثات قصيرة و جميلة من موزيلا عن فَيَرفُكس، و ثقافة الإنترنت، و أحيانا صرعة عشوائية من الإنترنت.",
  "settings_pane_done_button": "تمّ",
  "settings_pane_topstories_options_sponsored": "Show Sponsored Stories",
  "edit_topsites_button_text": "حرِّر",
  "edit_topsites_button_label": "خصص قسم المواقع الأكثر زيارة",
  "edit_topsites_showmore_button": "اعرض المزيد",
  "edit_topsites_showless_button": "اعرض أقل",
  "edit_topsites_done_button": "تمّ",
  "edit_topsites_pin_button": "ثبّت هذا الموقع",
  "edit_topsites_unpin_button": "افصل هذا الموقع",
  "edit_topsites_edit_button": "حرّر هذا الموقع",
  "edit_topsites_dismiss_button": "احذف هذا الموقع",
  "edit_topsites_add_button": "أضِفْ",
  "topsites_form_add_header": "موقع شائع جديد",
  "topsites_form_edit_header": "حرّر الموقع الشائع",
  "topsites_form_title_placeholder": "أدخل عنوانًا",
  "topsites_form_url_placeholder": "اكتب أو ألصق مسارًا",
  "topsites_form_add_button": "أضِفْ",
  "topsites_form_save_button": "احفظ",
  "topsites_form_cancel_button": "ألغِ",
  "topsites_form_url_validation": "مطلوب مسار صالح",
  "pocket_read_more": "المواضيع الشائعة:",
  "pocket_read_even_more": "اعرض المزيد من الأخبار",
  "pocket_feedback_header": "أفضل ما في الوِب، انتقاها أكثر من ٢٥ مليون شخص.",
  "pocket_description": "اكتشف محتوى عالي الجودة لربما قد فاتك دون هذا، بماسعدة من Pocket الذي أصبح الآن جزءا من موزيلا.",
  "highlights_empty_state": "ابدأ التصفح وسنعرض أمامك بعض المقالات والفيديوهات والمواقع الأخرى التي زرتها حديثا أو أضفتها إلى العلامات هنا.",
  "topstories_empty_state": "لا جديد. تحقق لاحقًا للحصول على مزيد من أهم الأخبار من {provider}. لا يمكنك الانتظار؟ اختر موضوعًا شائعًا للعثور على المزيد من القصص الرائعة من جميع أنحاء الوِب.",
  "manual_migration_explanation2": "جرب فَيَرفُكس مع العلامات، و التأريخ، و كلمات السر من متصفح آخر.",
  "manual_migration_cancel_button": "لا شكرًا",
  "manual_migration_import_button": "استورد الآن"
};

==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/ar/activity-stream-strings.js <==
// Note - this is a generated ar file.
window.gActivityStreamStrings = {
  "newtab_page_title": "لسان جديد",
  "header_top_sites": "المواقع الأكثر زيارة",
  "header_highlights": "أهم الأحداث",
  "header_recommended_by": "ينصح به {provider}",
  "context_menu_button_sr": "افتح قائمة {title} السياقية",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "مُزارة",
  "type_label_bookmarked": "معلّمة",
  "type_label_recommended": "مُتداول",
  "type_label_pocket": "Saved to Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "علّم",
  "menu_action_remove_bookmark": "أزل العلامة",
  "menu_action_open_new_window": "افتح في نافذة جديدة",
  "menu_action_open_private_window": "افتح في نافذة خاصة جديدة",
  "menu_action_dismiss": "ألغِ",
  "menu_action_delete": "احذف من التأريخ",
  "menu_action_pin": "ثبّت",
  "menu_action_unpin": "أزل",
  "confirm_history_delete_p1": "هل أنت متأكد أنك تريد حذف كل وجود لهذه الصفحة من تأريخك؟",
  "confirm_history_delete_notice_p2": "لا يمكن التراجع عن هذا الإجراء.",
  "menu_action_save_to_pocket": "احفظ في Pocket",
  "menu_action_delete_pocket": "Delete from Pocket",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "ابحث",
  "search_header": "بحث {search_engine_name}",
  "search_web_placeholder": "ابحث في الوِب",
  "section_disclaimer_topstories": "أكثر القصص تشويقًا على الإنترنت، مختارة بعناية بناء على ما تقرأه. من بوكِت، و الذي أصبح جزءًا من موزيلا.",
  "section_disclaimer_topstories_linktext": "اطلع على طريقة عملها.",
  "section_disclaimer_topstories_buttontext": "حسنًا، فهمت",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "خصص صفحة اللسان الجديد",
  "settings_pane_topsites_header": "المواقع الأكثر زيارة",
  "settings_pane_highlights_header": "أهم الأحداث",
  "settings_pane_highlights_options_bookmarks": "العلامات",
  "settings_pane_snippets_header": "المقتطفات",
  "edit_topsites_button_text": "حرِّر",
  "edit_topsites_edit_button": "حرّر هذا الموقع",
  "topsites_form_add_header": "موقع شائع جديد",
  "topsites_form_edit_header": "حرّر الموقع الشائع",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "أدخل عنوانًا",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "اكتب أو ألصق مسارًا",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "أضِفْ",
  "topsites_form_save_button": "احفظ",
  "topsites_form_cancel_button": "ألغِ",
  "topsites_form_url_validation": "مطلوب مسار صالح",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "المواضيع الشائعة:",
  "pocket_read_even_more": "اعرض المزيد من الأخبار",
  "highlights_empty_state": "ابدأ التصفح وسنعرض أمامك بعض المقالات والفيديوهات والمواقع الأخرى التي زرتها حديثا أو أضفتها إلى العلامات هنا.",
  "topstories_empty_state": "لا جديد. تحقق لاحقًا للحصول على مزيد من أهم الأخبار من {provider}. لا يمكنك الانتظار؟ اختر موضوعًا شائعًا للعثور على المزيد من القصص الرائعة من جميع أنحاء الوِب.",
  "manual_migration_explanation2": "جرب فَيَرفُكس مع العلامات، و التأريخ، و كلمات السر من متصفح آخر.",
  "manual_migration_cancel_button": "لا شكرًا",
  "manual_migration_import_button": "استورد الآن",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "default_label_loading": "يُحمّل…",
  "header_stories": "أهم الأخبار",
  "header_visit_again": "زرها مجددا",
  "header_bookmarks": "أحدث العلامات",
  "header_bookmarks_placeholder": "لا علامات لديك بعد.",
  "header_stories_from": "من",
  "type_label_synced": "مُزامنة من جهاز آخر",
  "type_label_open": "مفتوحة",
  "type_label_topic": "الموضوع",
  "type_label_now": "الآن",
  "menu_action_copy_address": "انسخ العنوان",
  "menu_action_email_link": "أرسل الرابط بالبريد…",
  "search_for_something_with": "ابحث عن {search_term} مستخدما:",
  "search_settings": "غيّر إعدادات البحث",
  "section_info_option": "المعلومات",
  "section_info_send_feedback": "أرسل انطباعك",
  "section_info_privacy_notice": "تنويه الخصوصية",
  "welcome_title": "مرحبًا في لسان جديد",
  "welcome_body": "سيستخدم فيرفكس هذا المكان لعرض أكثر العلامات، و المقالات، و الفيديوهات والصفحات التي زرتها مؤخرا، ليمكنك العودة إليها بسهولة.",
  "welcome_label": "تعرّف على أهم الأخبار",
  "time_label_less_than_minute": "< دقيقة",
  "time_label_minute": "{number} دقيقة",
  "time_label_hour": "{number} ساعة",
  "time_label_day": "{number} يوم",
  "settings_pane_header": "تفضيلات صفحة اللسان الجديد",
  "settings_pane_body2": "اختر ماتريد ان تراه في هذه الصفحه.",
  "settings_pane_search_header": "بحث",
  "settings_pane_search_body": "ابحث في الوِب من اللسان الجديد.",
  "settings_pane_topsites_body": "وصول للمواقع التي تزورها أكثر.",
  "settings_pane_topsites_options_showmore": "اعرض صفّين",
  "settings_pane_bookmarks_header": "أحدث العلامات",
  "settings_pane_bookmarks_body": "علاماتك المعلّمة حديثًا في مكان واحد.",
  "settings_pane_visit_again_header": "زرها مجددا",
  "settings_pane_visit_again_body": "سيعرض لك فَيَرفُكس بعضًا من تأريخ تصفحك الذي قد تود تذكّره لاحقًا.",
  "settings_pane_highlights_body2": "ارجع للأشياء المهمة التي زرتها مؤخرًا أو العلامات.",
  "settings_pane_highlights_options_visited": "المواقع المُزارة",
  "settings_pane_snippets_body": "اقرأ تحديثات قصيرة و جميلة من موزيلا عن فَيَرفُكس، و ثقافة الإنترنت، و أحيانا صرعة عشوائية من الإنترنت.",
  "settings_pane_done_button": "تمّ",
  "settings_pane_topstories_options_sponsored": "اعرض الأخبار الممولة",
  "edit_topsites_button_label": "خصص قسم المواقع الأكثر زيارة",
  "edit_topsites_showmore_button": "اعرض المزيد",
  "edit_topsites_showless_button": "اعرض أقل",
  "edit_topsites_done_button": "تمّ",
  "edit_topsites_pin_button": "ثبّت هذا الموقع",
  "edit_topsites_unpin_button": "افصل هذا الموقع",
  "edit_topsites_dismiss_button": "احذف هذا الموقع",
  "edit_topsites_add_button": "أضِفْ",
  "edit_topsites_add_button_tooltip": "أضف موقعًا شائعًا",
  "pocket_feedback_header": "أفضل ما في الوِب، انتقاها أكثر من ٢٥ مليون شخص.",
  "pocket_description": "اكتشف محتوى عالي الجودة لربما قد فاتك دون هذا، بماسعدة من Pocket الذي أصبح الآن جزءا من موزيلا."
};
